@@ -118,7 +118,7 @@ while((h = fstReaderIterateHier(xc)))
 				int sgna = 1, sgnb = 1;
 				pnt = lb_last + 1;
 				acc = 0;
-				while(isdigit(*pnt) || (*pnt == '-'))
+				while(isdigit((int)(unsigned char)*pnt) || (*pnt == '-'))
 					{
 					if(*pnt != '-')
 						{
@@ -141,7 +141,7 @@ while((h = fstReaderIterateHier(xc)))
 					{
 					pnt = col_last + 1;
 					acc = 0;
-					while(isdigit(*pnt) || (*pnt == '-'))	
+					while(isdigit((int)(unsigned char)*pnt) || (*pnt == '-'))	
 						{
 						if(*pnt != '-')
 							{
@@ -222,7 +222,7 @@ exponent_to_time_scale(scale);
 
 GLOBALS->numfacs=fstReaderGetVarCount(GLOBALS->fst_fst_c_1);
 GLOBALS->mvlfacs_fst_c_3=(struct fac *)calloc_2(GLOBALS->numfacs,sizeof(struct fac));
-f_name = calloc_2(GLOBALS->numfacs,sizeof(char *));
+f_name = calloc_2(F_NAME_MODULUS+1,sizeof(char *));
 GLOBALS->fst_table_fst_c_1=(struct lx2_entry *)calloc_2(GLOBALS->numfacs, sizeof(struct lx2_entry));
 sym_block = (struct symbol *)calloc_2(GLOBALS->numfacs, sizeof(struct symbol));
 node_block=(struct Node *)calloc_2(GLOBALS->numfacs,sizeof(struct Node));
@@ -331,12 +331,11 @@ if(GLOBALS->numfacs)
 	if(was_packed)
 		{
 		f_name[0] = pnt;
+		free_2(fnam);
 		}
 		else
 		{
-		int flen = strlen(fnam);
-		f_name[0]=malloc_2(flen+1);
-		strcpy(f_name[0], fnam);
+		f_name[0]=fnam;
 		}
 	}
 
@@ -461,27 +460,26 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 		if(was_packed)
 			{
-			f_name[i+1] = pnt;
+			f_name[(i+1)&F_NAME_MODULUS] = pnt;
+			free_2(fnam);
 			}
 			else
 			{
-			int flen = strlen(fnam);
-			f_name[i+1]=malloc_2(flen+1);
-			strcpy(f_name[i+1], fnam);
+			f_name[(i+1)&F_NAME_MODULUS]=fnam;
 			}
 		}
 
 	if(i>1)
 		{
-		free_2(f_name[i-2]);
-		f_name[i-2] = NULL;
+		free_2(f_name[(i-2)&F_NAME_MODULUS]);
+		f_name[(i-2)&F_NAME_MODULUS] = NULL;
 		}
 
 	f=GLOBALS->mvlfacs_fst_c_3+i;
 
 	if((f->len>1)&& (!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING))) )
 		{
-		int len=sprintf(buf, "%s[%d:%d]", f_name[i],GLOBALS->mvlfacs_fst_c_3[i].msb, GLOBALS->mvlfacs_fst_c_3[i].lsb);
+		int len=sprintf(buf, "%s[%d:%d]", f_name[(i)&F_NAME_MODULUS],GLOBALS->mvlfacs_fst_c_3[i].msb, GLOBALS->mvlfacs_fst_c_3[i].lsb);
 		str=malloc_2(len+1);
 
 		if(!GLOBALS->alt_hier_delimeter)
@@ -497,17 +495,17 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		prevsymroot = prevsym = NULL;
 
 		len = sprintf(buf, "%s[%d:%d]", pnam,GLOBALS->mvlfacs_fst_c_3[i].msb, GLOBALS->mvlfacs_fst_c_3[i].lsb);
-		fst_append_graft_chain(len, buf, i, ppar);
+		if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress)) fst_append_graft_chain(len, buf, i, ppar);
 		}
 	else if ( 
 			((f->len==1)&&(!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))&&
-			((i!=GLOBALS->numfacs-1)&&(!strcmp(f_name[i], f_name[i+1]))))
+			((i!=GLOBALS->numfacs-1)&&(!strcmp(f_name[(i)&F_NAME_MODULUS], f_name[(i+1)&F_NAME_MODULUS]))))
 			||
-			(((i!=0)&&(!strcmp(f_name[i], f_name[i-1]))) &&
+			(((i!=0)&&(!strcmp(f_name[(i)&F_NAME_MODULUS], f_name[(i-1)&F_NAME_MODULUS]))) &&
 			(GLOBALS->mvlfacs_fst_c_3[i].msb!=-1)&&(GLOBALS->mvlfacs_fst_c_3[i].lsb!=-1))
 		)
 		{
-		int len = sprintf(buf, "%s[%d]", f_name[i],GLOBALS->mvlfacs_fst_c_3[i].msb);
+		int len = sprintf(buf, "%s[%d]", f_name[(i)&F_NAME_MODULUS],GLOBALS->mvlfacs_fst_c_3[i].msb);
 		str=malloc_2(len+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
@@ -519,7 +517,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			}
 		s=&sym_block[i];
 	        symadd_name_exists_sym_exists(s,str,0);
-		if((allowed_to_autocoalesce)&&(prevsym)&&(i>0)&&(!strcmp(f_name[i], f_name[i-1]))&&(!strchr(f_name[i], '\\')))	/* allow chaining for search functions.. */
+		if((allowed_to_autocoalesce)&&(prevsym)&&(i>0)&&(!strcmp(f_name[(i)&F_NAME_MODULUS], f_name[(i-1)&F_NAME_MODULUS]))&&(!strchr(f_name[(i)&F_NAME_MODULUS], '\\')))	/* allow chaining for search functions.. */
 			{
 			prevsym->vec_root = prevsymroot;
 			prevsym->vec_chain = s;
@@ -532,18 +530,18 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			}
 
 		len = sprintf(buf, "%s[%d]", pnam,GLOBALS->mvlfacs_fst_c_3[i].msb);
-		fst_append_graft_chain(len, buf, i, ppar);
+		if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress)) fst_append_graft_chain(len, buf, i, ppar);
 		}
 		else
 		{
-		str=malloc_2(strlen(f_name[i])+1);
+		str=malloc_2(strlen(f_name[(i)&F_NAME_MODULUS])+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
-			strcpy(str, f_name[i]);
+			strcpy(str, f_name[(i)&F_NAME_MODULUS]);
 			}
 			else
 			{
-			strcpy_vcdalt(str, f_name[i], GLOBALS->alt_hier_delimeter);
+			strcpy_vcdalt(str, f_name[(i)&F_NAME_MODULUS], GLOBALS->alt_hier_delimeter);
 			}
 		s=&sym_block[i];
 	        symadd_name_exists_sym_exists(s,str,0);
@@ -556,7 +554,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			GLOBALS->mvlfacs_fst_c_3[i].len=32;
 			}
 
-		fst_append_graft_chain(strlen(pnam), pnam, i, ppar);
+		if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress)) fst_append_graft_chain(strlen(pnam), pnam, i, ppar);
 		}
 		
         n=&node_block[i];
@@ -580,7 +578,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 if(pnam2) { free_2(pnam2); pnam2 = NULL; }
 if(pnam) { free_2(pnam); pnam = NULL; }
 
-for(i=0;((i<2)&&(i<GLOBALS->numfacs));i++)
+for(i=0;i<=F_NAME_MODULUS;i++)
 	{
 	if(f_name[i])
 		{
@@ -1266,8 +1264,23 @@ for(txidxi=0;txidxi<GLOBALS->fst_maxhandle;txidxi++)
 }
 
 /*
- * $Id: fst.c,v 1.28 2010/06/02 03:51:30 gtkwave Exp $
+ * $Id: fst.c,v 1.33 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: fst.c,v $
+ * Revision 1.33  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
+ * Revision 1.32  2010/09/16 19:40:08  gtkwave
+ * back out hierarchy removal
+ *
+ * Revision 1.31  2010/09/16 19:23:37  gtkwave
+ * duplicate tree fix for when compressed facilities are being used
+ *
+ * Revision 1.30  2010/09/15 18:35:42  gtkwave
+ * added F_NAME_MODULUS to reduce temp memory usage
+ *
+ * Revision 1.29  2010/09/14 21:51:39  gtkwave
+ * fixed dangling fnam alloc
+ *
  * Revision 1.28  2010/06/02 03:51:30  gtkwave
  * don't autocoalesce escape identifiers
  *
