@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2006.
+ * Copyright (c) Tony Bybell 2006-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -11,7 +11,9 @@
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
-
+#ifdef __MINGW32__
+#include <windows.h>
+#endif
 #include "wave_locale.h"
 
 #include <sys/time.h>
@@ -20,7 +22,7 @@
 
 #include "debug.h"
 
-#if !defined _MSC_VER && !defined __MINGW32__ && !defined OS_X && defined WAVE_USE_GTK2
+#if !defined _MSC_VER && !defined OS_X && defined WAVE_USE_GTK2
 
 static int plug_removed(GtkWidget *widget, gpointer data)
 {
@@ -55,6 +57,10 @@ int shmid;
 GtkWidget *main_vbox, *mainwindow, *vpan;
 int i;
 int split_point = -1;
+#ifdef __MINGW32__
+char mapName[65];
+HANDLE hMapFile;
+#endif
 
 GtkWidget *xsocket[2] = { NULL, NULL };
 
@@ -117,6 +123,181 @@ gtk_signal_connect(GTK_OBJECT(xsocket[1]), "plug-removed", GTK_SIGNAL_FUNC(plug_
 
 gtk_paned_pack2 (GTK_PANED (vpan), xsocket[1], TRUE, FALSE);
 
+#ifdef __MINGW32__
+shmid = getpid();
+sprintf(mapName, "twinwave%d", shmid);
+hMapFile = CreateFileMapping(INVALID_HANDLE_VALUE, NULL, PAGE_READWRITE, 0, 2 * sizeof(struct gtkwave_dual_ipc_t), mapName);
+if(hMapFile != NULL)
+        {
+        dual_ctx = MapViewOfFile(hMapFile, FILE_MAP_ALL_ACCESS, 0, 0, 2 * sizeof(struct gtkwave_dual_ipc_t));
+
+        if(dual_ctx)
+               	{
+               	memset(dual_ctx, 0, 2 * sizeof(struct gtkwave_dual_ipc_t));
+               	memcpy(&dual_ctx[0].matchword, DUAL_MATCHWORD, 4);
+               	memcpy(&dual_ctx[1].matchword, DUAL_MATCHWORD, 4);
+
+		/* child 0 */
+				{
+				int idx;
+				int n_items = split_point + 5;
+				int slen;
+				char **arglist = calloc(n_items, sizeof(char *));
+				char *mylist;
+				STARTUPINFO si;
+				PROCESS_INFORMATION pi;
+				BOOL rc;
+
+				memset(&si, 0, sizeof(STARTUPINFO));
+				memset(&pi, 0, sizeof(PROCESS_INFORMATION));
+
+				sprintf(buf, "0+%08X", shmid);
+				sprintf(buf2, "%x", gtk_socket_get_id (GTK_SOCKET(xsocket[0])));
+
+				arglist[0] = "gtkwave.exe";
+				arglist[1] = "-D";
+				arglist[2] = buf;
+				arglist[3] = "-X";
+				arglist[4] = buf2;
+
+				for(i=1;i<split_point;i++)
+					{
+					arglist[i+4] = argv[i];
+					}
+
+				arglist[i+4] = NULL;
+
+				slen = 1;
+				for(idx=0;idx<i+4;idx++)
+					{
+					slen += strlen(arglist[idx]);
+					slen++;
+					}
+				mylist = calloc(1, slen);
+				for(idx=0;idx<i+4;idx++)
+					{
+					strcat(mylist, arglist[idx]);
+					strcat(mylist, " ");
+					}
+
+				si.cb = sizeof(si);
+
+				rc = CreateProcess(
+					arglist[0],
+					mylist,
+					NULL,
+					NULL,
+					FALSE,
+					0,
+					NULL,
+					NULL,
+					&si,
+					&pi);
+			
+				if(!rc) 
+					{
+					fprintf(stderr, "Child 0 failed '%s' '%s'\n", arglist[0], mylist);
+					exit(255);
+					}
+
+				free(mylist);
+				free(arglist);
+				}
+
+		/* child 1 */
+				{
+				int idx;
+				int n_items = argc - split_point + 5;
+				int slen;
+				char **arglist = calloc(n_items, sizeof(char *));
+				char *mylist;
+				STARTUPINFO si;
+				PROCESS_INFORMATION pi;
+				BOOL rc;
+
+				memset(&si, 0, sizeof(STARTUPINFO));
+				memset(&pi, 0, sizeof(PROCESS_INFORMATION));
+
+				sprintf(buf, "1+%08X", shmid);
+				sprintf(buf2, "%x", gtk_socket_get_id (GTK_SOCKET(xsocket[1])));
+
+				arglist[0] = "gtkwave.exe";
+				arglist[1] = "-D";
+				arglist[2] = buf;
+				arglist[3] = "-X";
+				arglist[4] = buf2;
+
+				for(i=split_point+1;i<argc;i++)
+					{
+					arglist[i-split_point+4] = argv[i];
+					}
+
+				i-=split_point;
+				arglist[i+4] = NULL;
+
+				slen = 1;
+				for(idx=0;idx<i+4;idx++)
+					{
+					slen += strlen(arglist[idx]);
+					slen++;
+					}
+				mylist = calloc(1, slen);
+				for(idx=0;idx<i+4;idx++)
+					{
+					strcat(mylist, arglist[idx]);
+					strcat(mylist, " ");
+					}
+
+				si.cb = sizeof(si);
+
+				rc = CreateProcess(
+					arglist[0],
+					mylist,
+					NULL,
+					NULL,
+					FALSE,
+					0,
+					NULL,
+					NULL,
+					&si,
+					&pi);
+			
+				if(!rc) 
+					{
+					fprintf(stderr, "Child 1 failed '%s' '%s'\n", arglist[0], mylist);
+					exit(255);
+					}
+
+				free(mylist);
+				free(arglist);
+				}
+
+
+		for(;;)
+			{
+			Sleep(1000 / 5);
+			while (gtk_events_pending()) gtk_main_iteration();
+
+			if((!dual_ctx[0].viewer_is_initialized)&&(dual_ctx[1].viewer_is_initialized))
+				{
+				gtk_window_set_title(GTK_WINDOW(mainwindow), "TwinWave Waiting on Viewer #1");
+				}
+			else
+			if((dual_ctx[0].viewer_is_initialized)&&(!dual_ctx[1].viewer_is_initialized))
+				{
+				gtk_window_set_title(GTK_WINDOW(mainwindow), "TwinWave Waiting on Viewer #2");
+				}
+			else
+			if((dual_ctx[0].viewer_is_initialized)&&(dual_ctx[1].viewer_is_initialized))
+				{
+				gtk_window_set_title(GTK_WINDOW(mainwindow), "TwinWave");
+				break;
+				}
+			}
+		gtk_main();
+		}
+	}
+#else
 shmid = shmget(0, 2 * sizeof(struct gtkwave_dual_ipc_t), IPC_CREAT | 0600 );
 if(shmid >=0)
 	{
@@ -226,6 +407,7 @@ if(shmid >=0)
 			}
 		}
 	}
+#endif
 
 return(0);
 }
@@ -254,8 +436,11 @@ return(255);
 #endif
 
 /*
- * $Id: twinwave.c,v 1.3 2007/09/12 17:26:45 gtkwave Exp $
+ * $Id: twinwave.c,v 1.4 2009/04/23 19:38:50 gtkwave Exp $
  * $Log: twinwave.c,v $
+ * Revision 1.4  2009/04/23 19:38:50  gtkwave
+ * add mingw support to twinwave
+ *
  * Revision 1.3  2007/09/12 17:26:45  gtkwave
  * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
  *
