@@ -2284,11 +2284,10 @@ while(v)
 Pvoid_t  PJArray = GLOBALS->sym_judy;   
 PPvoid_t PPValue;
 char *Index = calloc_2(1, longest);
-JError_t JError;
                                 
-for (PPValue  = JudySLFirst (PJArray, (uint8_t *)Index, &JError);
+for (PPValue  = JudySLFirst (PJArray, (uint8_t *)Index, PJE0);
          PPValue != (PPvoid_t) NULL;
-         PPValue  = JudySLNext  (PJArray, (uint8_t *)Index, &JError))
+         PPValue  = JudySLNext  (PJArray, (uint8_t *)Index, PJE0))
     {
         struct symbol *s = *(struct symbol **)PPValue;
         s->name = strdup_2(Index);
@@ -2618,8 +2617,11 @@ return(GLOBALS->max_time);
 /*******************************************************************************/
 
 /*
- * $Id: vcd.c,v 1.36 2010/11/05 18:36:20 gtkwave Exp $
+ * $Id: vcd.c,v 1.37 2010/11/19 06:47:16 gtkwave Exp $
  * $Log: vcd.c,v $
+ * Revision 1.37  2010/11/19 06:47:16  gtkwave
+ * use PJE0 macro for unuser error return on judy function calls
+ *
  * Revision 1.36  2010/11/05 18:36:20  gtkwave
  * update large file size warning to refer to fst instead
  *
